@@ -2,11 +2,12 @@ package Test::SharedFork;
 use strict;
 use warnings;
 use base 'Test::Builder::Module';
-our $VERSION = '0.14';
+our $VERSION = '0.16';
 use Test::Builder 0.32; # 0.32 or later is needed
 use Test::SharedFork::Scalar;
 use Test::SharedFork::Array;
 use Test::SharedFork::Store;
+use Config;
 use 5.008000;
 
 {
@@ -45,6 +46,10 @@ my $STORE;
 BEGIN {
     my $builder = __PACKAGE__->builder;
 
+    if( $] >= 5.008001 && $Config{useithreads} && $INC{'threads.pm'} ) {
+        die "# Current version of Test::SharedFork does not supports ithreads.";
+    }
+
     if (Test::Builder->VERSION > 2.00) {
         # new Test::Builder
         $STORE = Test::SharedFork::Store->new();
@@ -146,10 +151,15 @@ Test::SharedFork - fork test
 =head1 DESCRIPTION
 
 Test::SharedFork is utility module for Test::Builder.
-This module makes forking test!
+
+This module makes L<fork(2)> safety in your test case.
 
 This module merges test count with parent process & child process.
 
+=head1 LIMITATIONS
+
+This version of the Test::SharedFork does not support ithreads, because L<threads::shared> conflicts with L<Storable>.
+
 =head1 AUTHOR
 
 Tokuhiro Matsuno E<lt>tokuhirom  slkjfd gmail.comE<gt>
